@@ -64,10 +64,10 @@ public:
      */
     ~KCompletionBox();
 
-    virtual QSize sizeHint() const;
+    QSize sizeHint() const Q_DECL_OVERRIDE;
 
     /**
-     * @returns true if selecting an item results in the emition of the selected() signal.
+     * @returns true if selecting an item results in the emission of the selected() signal.
      */
     bool activateOnSelect() const;
 
@@ -180,10 +180,10 @@ public Q_SLOTS:
     void end();
 
     /**
-     * Re-implemented for internal reasons.  API is unaffected.
+     * Reimplemented for internal reasons. API is unaffected.
      * Call it only if you really need it (i.e. the widget was hidden before) to have better performance.
      */
-    virtual void setVisible(bool visible);
+    void setVisible(bool visible) Q_DECL_OVERRIDE;
 
 Q_SIGNALS:
     /**
@@ -194,7 +194,7 @@ Q_SIGNALS:
 
     /**
      * Emitted whenever the user chooses to ignore the available
-     * selections and close the this box.
+     * selections and closes this box.
      */
     void userCancelled(const QString &);
 
@@ -227,7 +227,7 @@ protected:
      * Reimplemented from QListWidget to get events from the viewport (to hide
      * this widget on mouse-click, Escape-presses, etc.
      */
-    virtual bool eventFilter(QObject *, QEvent *);
+    bool eventFilter(QObject *, QEvent *) Q_DECL_OVERRIDE;
 
     /**
      * The preferred global coordinate at which the completion box's top left corner
@@ -245,8 +245,7 @@ protected Q_SLOTS:
 private:
     const QScopedPointer<KCompletionBoxPrivate> d_ptr;
 
-    Q_PRIVATE_SLOT(d_func(), void cancelled())
-    Q_PRIVATE_SLOT(d_func(), void slotItemClicked(QListWidgetItem *))
+    Q_PRIVATE_SLOT(d_func(), void _k_itemClicked(QListWidgetItem *))
 };
 
 #endif // KCOMPLETIONBOX_H
